==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/HcxEnterpriseSite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [HcxEnterpriseSite].
 */
@PulumiTagMarker
public class HcxEnterpriseSiteResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: HcxEnterpriseSiteArgs = HcxEnterpriseSiteArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend HcxEnterpriseSiteArgsBuilder.() -> Unit) {
        val builder = HcxEnterpriseSiteArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): HcxEnterpriseSite {
        val builtJavaResource = com.pulumi.azurenative.avs.HcxEnterpriseSite(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return HcxEnterpriseSite(builtJavaResource)
    }
}

/**
 * An HCX Enterprise Site resource
 * Azure REST API version: 2022-05-01. Prior API version in Azure Native 1.x: 2020-03-20.
 * Other available API versions: 2023-03-01.
 * ## Example Usage
 * ### HcxEnterpriseSites_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var hcxEnterpriseSite = new AzureNative.AVS.HcxEnterpriseSite("hcxEnterpriseSite", new()
 *     {
 *         HcxEnterpriseSiteName = "site1",
 *         PrivateCloudName = "cloud1",
 *         ResourceGroupName = "group1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/avs/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := avs.NewHcxEnterpriseSite(ctx, "hcxEnterpriseSite", &avs.HcxEnterpriseSiteArgs{
 * 			HcxEnterpriseSiteName: pulumi.String("site1"),
 * 			PrivateCloudName:      pulumi.String("cloud1"),
 * 			ResourceGroupName:     pulumi.String("group1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.avs.HcxEnterpriseSite;
 * import com.pulumi.azurenative.avs.HcxEnterpriseSiteArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var hcxEnterpriseSite = new HcxEnterpriseSite("hcxEnterpriseSite", HcxEnterpriseSiteArgs.builder()
 *             .hcxEnterpriseSiteName("site1")
 *             .privateCloudName("cloud1")
 *             .resourceGroupName("group1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:avs:HcxEnterpriseSite site1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AVS/privateClouds/{privateCloudName}/hcxEnterpriseSites/{hcxEnterpriseSiteName}
 * ```
 */
public class HcxEnterpriseSite internal constructor(
    override val javaResource: com.pulumi.azurenative.avs.HcxEnterpriseSite,
) : KotlinCustomResource(javaResource, HcxEnterpriseSiteMapper) {
    /**
     * The activation key
     */
    public val activationKey: Output<String>
        get() = javaResource.activationKey().applyValue({ args0 -> args0 })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The status of the HCX Enterprise Site
     */
    public val status: Output<String>
        get() = javaResource.status().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object HcxEnterpriseSiteMapper : ResourceMapper<HcxEnterpriseSite> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.avs.HcxEnterpriseSite::class == javaResource::class

    override fun map(javaResource: Resource): HcxEnterpriseSite = HcxEnterpriseSite(
        javaResource as
            com.pulumi.azurenative.avs.HcxEnterpriseSite,
    )
}

/**
 * @see [HcxEnterpriseSite].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [HcxEnterpriseSite].
 */
public suspend fun hcxEnterpriseSite(
    name: String,
    block: suspend HcxEnterpriseSiteResourceBuilder.() -> Unit,
): HcxEnterpriseSite {
    val builder = HcxEnterpriseSiteResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [HcxEnterpriseSite].
 * @param name The _unique_ name of the resulting resource.
 */
public fun hcxEnterpriseSite(name: String): HcxEnterpriseSite {
    val builder = HcxEnterpriseSiteResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/avs/kotlin/HcxEnterpriseSite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [HcxEnterpriseSite].
 */
@PulumiTagMarker
public class HcxEnterpriseSiteResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: HcxEnterpriseSiteArgs = HcxEnterpriseSiteArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend HcxEnterpriseSiteArgsBuilder.() -> Unit) {
        val builder = HcxEnterpriseSiteArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): HcxEnterpriseSite {
        val builtJavaResource = com.pulumi.azurenative.avs.HcxEnterpriseSite(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return HcxEnterpriseSite(builtJavaResource)
    }
}

/**
 * An HCX Enterprise Site resource
 * Azure REST API version: 2022-05-01. Prior API version in Azure Native 1.x: 2020-03-20.
 * Other available API versions: 2023-03-01, 2023-09-01.
 * ## Example Usage
 * ### HcxEnterpriseSites_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var hcxEnterpriseSite = new AzureNative.AVS.HcxEnterpriseSite("hcxEnterpriseSite", new()
 *     {
 *         HcxEnterpriseSiteName = "site1",
 *         PrivateCloudName = "cloud1",
 *         ResourceGroupName = "group1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/avs/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := avs.NewHcxEnterpriseSite(ctx, "hcxEnterpriseSite", &avs.HcxEnterpriseSiteArgs{
 * 			HcxEnterpriseSiteName: pulumi.String("site1"),
 * 			PrivateCloudName:      pulumi.String("cloud1"),
 * 			ResourceGroupName:     pulumi.String("group1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.avs.HcxEnterpriseSite;
 * import com.pulumi.azurenative.avs.HcxEnterpriseSiteArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var hcxEnterpriseSite = new HcxEnterpriseSite("hcxEnterpriseSite", HcxEnterpriseSiteArgs.builder()
 *             .hcxEnterpriseSiteName("site1")
 *             .privateCloudName("cloud1")
 *             .resourceGroupName("group1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:avs:HcxEnterpriseSite site1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AVS/privateClouds/{privateCloudName}/hcxEnterpriseSites/{hcxEnterpriseSiteName}
 * ```
 */
public class HcxEnterpriseSite internal constructor(
    override val javaResource: com.pulumi.azurenative.avs.HcxEnterpriseSite,
) : KotlinCustomResource(javaResource, HcxEnterpriseSiteMapper) {
    /**
     * The activation key
     */
    public val activationKey: Output<String>
        get() = javaResource.activationKey().applyValue({ args0 -> args0 })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The status of the HCX Enterprise Site
     */
    public val status: Output<String>
        get() = javaResource.status().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object HcxEnterpriseSiteMapper : ResourceMapper<HcxEnterpriseSite> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.avs.HcxEnterpriseSite::class == javaResource::class

    override fun map(javaResource: Resource): HcxEnterpriseSite = HcxEnterpriseSite(
        javaResource as
            com.pulumi.azurenative.avs.HcxEnterpriseSite,
    )
}

/**
 * @see [HcxEnterpriseSite].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [HcxEnterpriseSite].
 */
public suspend fun hcxEnterpriseSite(
    name: String,
    block: suspend HcxEnterpriseSiteResourceBuilder.() -> Unit,
): HcxEnterpriseSite {
    val builder = HcxEnterpriseSiteResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [HcxEnterpriseSite].
 * @param name The _unique_ name of the resulting resource.
 */
public fun hcxEnterpriseSite(name: String): HcxEnterpriseSite {
    val builder = HcxEnterpriseSiteResourceBuilder()
    builder.name(name)
    return builder.build()
}
